import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { createElement as _createElement } from "react";
import React from 'react';
import { isEqual } from 'lodash';
import { ArrowDropDown as ArrowDropDownIcon } from '@mui/icons-material';
import { Close as CloseIcon } from '@mui/icons-material';
import { Autocomplete, Box, Chip, TextField, Typography, } from '@mui/material';
import CrossIcon from '../../assets/icons/cross.svg';
import InfoIcon from '../../assets/icons/info.svg';
import { VariantTypes } from '../../constants/common-constants';
import { translate } from '../../locales/translations';
import AdminTooltip from '../tooltip/AdminTooltip';
import './adminDropdown-styles.scss';
const AdminDropdown = (props) => {
    const { containerClass = '', data, disabled, helperText = '', error = false, isMultiple = false, isOptional = false, isReadOnly = false, label = '', labelClass = '', maxSelectLimit, placeholder = 'Select an option...', renderOption = defaultRenderOption, onChange = () => { }, value = null, tooltipMessage, } = props;
    function defaultRenderOption(props, option) {
        const { label } = option;
        return (_createElement(Box, { component: "li", ...props, className: "adminDropdown__optionContainer", key: option.id },
            _jsx(Typography, { className: "adminDropdown__optionLabel", children: label })));
    }
    const renderInput = (params) => (_jsx(TextField, { ...params, inputProps: {
            ...params.inputProps,
            placeholder,
        }, variant: VariantTypes.Outlined, className: `adminDropdown__textfield ${helperText ? 'adminDropdown__errorField' : ''}`, helperText: error && helperText ? helperText : '', error: error }));
    const handleChange = (_event, newValue, _changeReason, details) => {
        if (_changeReason === 'clear') {
            onChange(null);
            return;
        }
        if (isMultiple && Array.isArray(newValue)) {
            const multipleValue = value;
            const newValues = [];
            // option selected by the user
            const { option } = details || {};
            let isOptionAlreadySelected = false;
            multipleValue.forEach(item => {
                if (item === option?.id) {
                    isOptionAlreadySelected = true;
                }
            });
            // toggle the selection of option, if already selected
            if (isOptionAlreadySelected) {
                const idx = multipleValue.findIndex(item => item === option?.id);
                newValues.push(...multipleValue.slice(0, idx));
                newValues.push(...multipleValue.slice(idx + 1, multipleValue.length));
            }
            else {
                newValues.push(...multipleValue);
                option?.id && newValues.push(option.id);
            }
            // sort the selected options WRT their order in data
            onChange(newValues);
        }
        else {
            const singleValue = newValue;
            onChange(singleValue.id);
        }
    };
    const renderChipsTags = (value, getTagProps) => {
        return value?.map((option, index) => (_createElement(Chip, { ...getTagProps({ index }), label: option.label, key: option.id, deleteIcon: _jsx(CrossIcon, {}), className: "adminDropdown__chip" })));
    };
    const getValue = () => {
        let res = null;
        if (isMultiple && Array.isArray(value)) {
            const multipleValue = value;
            res = data.filter(eachItem => multipleValue.includes(eachItem.id ?? ''));
        }
        else {
            res = value ? data.find(eachItem => eachItem.id === value) : null;
        }
        return res;
    };
    const getOptionDisabled = (option) => {
        const isMaxLimitReached = !!maxSelectLimit && Array.isArray(value) && value.length >= maxSelectLimit;
        const selectedValues = getValue();
        const isSameTypeSelected = Array.isArray(value) &&
            selectedValues?.some((selectedOption) => selectedOption?.type === option?.type);
        return isMaxLimitReached || option.isDisabled || isSameTypeSelected || false;
    };
    return (_jsxs("div", { className: `adminDropdown__container ${containerClass}`, children: [_jsxs(Typography, { className: labelClass, children: [label, !!tooltipMessage && (_jsx(AdminTooltip, { message: tooltipMessage, isDarkMode: true, children: _jsx(InfoIcon, {}) })), isOptional && (_jsx("span", { className: "adminDropdown__optionalLabel", children: translate.common.optional }))] }), _jsx(Autocomplete, { autoComplete: true, autoHighlight: true, className: "adminDropdown__Dropdown", clearIcon: _jsx(CloseIcon, { onClick: e => {
                        handleChange(e, null, 'clear');
                    }, fontSize: "small" }), getOptionLabel: option => option.label, getOptionDisabled: getOptionDisabled, multiple: isMultiple, onChange: handleChange, options: data, popupIcon: _jsx(ArrowDropDownIcon, {}), readOnly: isReadOnly, renderInput: renderInput, renderOption: renderOption, renderTags: renderChipsTags, value: getValue(), disabled: disabled })] }));
};
const arePropsEqual = (prevProps, nextProps) => {
    return isEqual(prevProps, nextProps);
};
export default React.memo(AdminDropdown, arePropsEqual);
