import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { observer } from 'mobx-react-lite';
import { AdminButton, AdminInput } from '../../components';
import { ButtonVariant, InputPresets, ToastPreset } from '../../constants';
import { translate } from '../../locales/translations';
import { useStore } from '../../models';
import { changePassword, logOut } from '../../utils';
import './changePassword-styles.scss';
const ChangePassword = observer((props) => {
    const { onClose } = props;
    const store = useStore();
    const { viewStore } = store;
    const { toastStore } = viewStore;
    const { popToast } = toastStore;
    const [currentPassword, setCurrentPassword] = useState('');
    const [newPassword, setNewPassword] = useState('');
    const [confirmNewPassword, setConfirmNewPassword] = useState('');
    const [errors, setErrors] = useState({
        currentPassword: '',
        newPassword: '',
        confirmNewPassword: '',
    });
    const handleCurrentPasswordChange = (value) => {
        setCurrentPassword(String(value));
    };
    const handleNewPasswordChange = (value) => {
        setNewPassword(String(value));
    };
    const handleConfirmNewPasswordChange = (value) => {
        setConfirmNewPassword(String(value));
    };
    const handleChangePasswordClick = async () => {
        try {
            if (!currentPassword || !newPassword || !confirmNewPassword) {
                setErrors({
                    currentPassword: currentPassword
                        ? ''
                        : translate.pages.changePassword.currentPasswordError,
                    newPassword: newPassword ? '' : translate.pages.changePassword.newPasswordError,
                    confirmNewPassword: confirmNewPassword
                        ? ''
                        : translate.pages.changePassword.confirmNewPasswordError,
                });
                return;
            }
            if (newPassword === currentPassword) {
                setErrors({
                    currentPassword: '',
                    newPassword: translate.pages.changePassword.passwordMatch,
                    confirmNewPassword: '',
                });
                return;
            }
            else if (newPassword !== confirmNewPassword) {
                setErrors({
                    currentPassword: '',
                    newPassword: translate.pages.changePassword.passwordMismatch,
                    confirmNewPassword: translate.pages.changePassword.passwordMismatch,
                });
                return;
            }
            const isPasswordChange = await changePassword(currentPassword, newPassword);
            if (!isPasswordChange) {
                setErrors({
                    currentPassword: translate.pages.changePassword.currentPasswordWrong,
                    newPassword: '',
                    confirmNewPassword: '',
                });
            }
            else {
                onClose();
                popToast({
                    type: ToastPreset.Success,
                    message: translate.pages.changePassword.passwordChangeSuccess,
                });
                setTimeout(() => {
                    logOut();
                }, 3000);
            }
        }
        catch (error) {
            console.log('Error', error);
        }
    };
    return (_jsxs("div", { className: "changePassword__container", children: [_jsxs("div", { className: "changePassword__form", children: [_jsx(AdminInput, { containerClass: "changePassword__input", error: !!errors.currentPassword, helperText: errors.currentPassword, label: translate.pages.changePassword.currentPassword, onChange: handleCurrentPasswordChange, preset: InputPresets.Password, value: currentPassword }), _jsx(AdminInput, { containerClass: "changePassword__input", error: !!errors.newPassword, helperText: errors.newPassword, label: translate.pages.changePassword.newPassword, onChange: handleNewPasswordChange, preset: InputPresets.Password, value: newPassword }), _jsx(AdminInput, { containerClass: "changePassword__input", error: !!errors.confirmNewPassword, helperText: errors.confirmNewPassword, label: translate.pages.changePassword.confirmNewPassword, onChange: handleConfirmNewPasswordChange, preset: InputPresets.Password, value: confirmNewPassword })] }), _jsx(AdminButton, { handleClick: handleChangePasswordClick, title: translate.pages.changePassword.buttonTitle, variant: ButtonVariant.Outlined })] }));
});
export default ChangePassword;
