import { toast } from 'react-toastify';
import qs from 'qs';
/** validate regex */
export const validateRegex = (email, regex) => {
    return regex.test(email);
};
export const removeKeyFromQueryString = (queryString, key) => {
    const queryObj = qs.parse(queryString, { ignoreQueryPrefix: true });
    if (queryObj[key]) {
        delete queryObj[key];
    }
    return qs.stringify(queryObj, { addQueryPrefix: true });
};
/** get local storage value */
export const getLocalStorageValue = (key) => {
    const storedValue = localStorage.getItem(key);
    return storedValue !== null ? JSON.parse(storedValue) : null;
};
/** to convert snake case to title case */
export const convertSnakeCaseToTitleCase = (value) => {
    return value
        .split('_')
        .map(word => word.charAt(0).toUpperCase() + word.slice(1))
        .join(' ');
};
/**
 * To download a file or a resource from a URL
 * @param file Optional File object to download
 * @param url Optional URL of the resource to download
 */
export const downloadFile = (file, url) => {
    if (file) {
        const objectURL = URL.createObjectURL(file);
        const link = document.createElement('a');
        link.href = objectURL;
        link.download = file.name;
        link.click();
        URL.revokeObjectURL(objectURL);
    }
    else if (url) {
        const link = document.createElement('a');
        link.href = url;
        link.download = url.split('/').pop() || 'file';
        link.click();
    }
    else {
        console.error('No file or URL provided for download');
    }
};
export const notifySuccess = (message) => toast.success(message);
export const notifyError = (message) => toast.error(message);
export const notifyWarning = (message) => toast.warn(message);
