import { EmailAuthProvider, GoogleAuthProvider, getAuth, onAuthStateChanged, reauthenticateWithCredential, sendPasswordResetEmail, signInWithEmailAndPassword, signInWithPopup, signOut, updatePassword, } from 'firebase/auth';
import { auth } from '../../firebase';
const provider = new GoogleAuthProvider();
export const loginWithEmailPassword = async (email, password) => {
    try {
        const result = await signInWithEmailAndPassword(auth, email, password);
        return result;
    }
    catch (error) {
        console.error('Sign in error: ', error);
    }
};
export const forgotPassword = async (email) => {
    const auth = getAuth();
    try {
        await sendPasswordResetEmail(auth, email);
        return 'Password reset email sent';
    }
    catch (error) {
        console.error('Forgot Password error:', error);
        throw error;
    }
};
export const logOut = async () => {
    await signOut(auth);
};
export const changePassword = async (currentPassword, newPassword) => {
    const auth = getAuth();
    const user = auth?.currentUser;
    const email = user?.email;
    if (user && email) {
        try {
            const credential = EmailAuthProvider.credential(email, currentPassword);
            await reauthenticateWithCredential(user, credential);
            await updatePassword(user, newPassword);
            console.log('Password updated successfully');
            return true;
        }
        catch (error) {
            if (error.code === 'auth/wrong-password') {
                console.error('Incorrect current password.');
                return false;
            }
            else {
                console.error('Error updating password:', error);
            }
        }
    }
    else {
        console.error('No user is currently logged in');
    }
};
export const getUserToken = async () => {
    return new Promise((resolve, reject) => {
        onAuthStateChanged(auth, async (user) => {
            if (user) {
                try {
                    const accessToken = await user.getIdToken(true);
                    console.log('User Token', accessToken);
                    resolve({ accessToken });
                }
                catch (error) {
                    console.error('onAuthStateChanged:::Error getting token:', error);
                    reject(error);
                }
            }
            else {
                console.log('onAuthStateChanged:::No user is signed in.');
                reject(null);
            }
        });
    });
};
export const signInWithGooglePopup = () => signInWithPopup(auth, provider);
